@@ -1,9 +1,13 @@
 """CPython API Methods and intrinsic constants."""
+from __future__ import annotations
+
 import ctypes
-from ctypes import POINTER, c_void_p, py_object, pythonapi, sizeof
-from typing import Callable, Union
+from collections.abc import Sequence
+from ctypes import POINTER, Array, c_size_t, c_void_p, py_object, pythonapi, sizeof
+from typing import Callable, TypeVar, Union
 
 import _ctypes
+from typing_extensions import Annotated
 
 from einspect.compat import Version, python_req
 from einspect.protocols.delayed_bind import bind_api
@@ -19,6 +23,9 @@ __all__ = (
     "align_size",
 )
 
+_T = TypeVar("_T")
+_CT = TypeVar("_CT")
+
 Py_ssize_t = ctypes.c_ssize_t
 """Constant for type Py_ssize_t."""
 
@@ -42,7 +49,6 @@ else:  # pragma: no cover
     ALIGNMENT_SHIFT = 3
 
 
-# noinspection PyPep8Naming
 class Py:
     """Typed methods from pythonapi."""
 
@@ -116,7 +122,6 @@ class Py:
         Resize.argtypes = (POINTER(py_object), Py_ssize_t)  # type: ignore
         Resize.restype = None  # type: ignore
 
-    # noinspection PyPep8Naming
     class Type:
         @bind_api(pythonapi["PyType_Modified"])
         @staticmethod
@@ -128,6 +133,57 @@ class Py:
               or base classes of the type.
             """
 
+    class Mem:
+        @bind_api(pythonapi["PyMem_Malloc"])
+        @staticmethod
+        def Malloc(n: Annotated[int, c_size_t]) -> c_void_p:
+            """
+            Allocates n bytes and returns a pointer of type void* to the allocated memory,
+            or NULL if the request fails.
+
+            Requesting zero bytes returns a distinct non-NULL pointer if possible,
+            as if PyMem_Malloc(1) had been called instead. The memory will not
+            have been initialized in any way.
+
+            https://docs.python.org/3/c-api/memory.htm
+            """
+
+        @bind_api(pythonapi["PyMem_Calloc"])
+        @staticmethod
+        def Calloc(
+            nelem: Annotated[int, c_size_t], elsize: Annotated[int, c_size_t]
+        ) -> c_void_p:
+            """
+            Allocates nelem elements each whose size in bytes is elsize and
+            returns  The memory is initialized to zeros.
+
+            Requesting zero elements or elements of size zero bytes
+            returns a distinct non-NULL pointer if possible,
+            as if PyMem_Calloc(1, 1) had been called instead.
+
+            Args:
+                nelem: Number of elements.
+                elsize: Size of each element in bytes.
+
+            Returns:
+                A pointer to the allocated memory, or NULL if the request fails.
+            """
+
+        @bind_api(pythonapi["PyMem_Realloc"])
+        @staticmethod
+        def Realloc(p: c_void_p, n: Annotated[int, c_size_t]) -> c_void_p:
+            """
+            Resizes the memory block pointed to by p to n bytes.
+            The contents will be unchanged to the minimum of the old and the new sizes.
+
+            Args:
+                p: Pointer to the memory block to be resized.
+                n: New size in bytes.
+
+            Returns:
+                Pointer p, or NULL if request fails (p remains a valid pointer).
+            """
+
 
 PyObj_FromPtr: Callable[[IntSize], object] = _ctypes.PyObj_FromPtr
 """(Py_ssize_t ptr) -> Py_ssize_t"""
@@ -136,3 +192,11 @@ PyObj_FromPtr: Callable[[IntSize], object] = _ctypes.PyObj_FromPtr
 def align_size(size: int, alignment: int = ALIGNMENT) -> int:
     """Align size to alignment."""
     return (size + alignment - 1) & ~(alignment - 1)
+
+
+def seq_to_array(seq: Sequence[_T] | Array[_T], dtype: type[_CT]) -> Array[_CT]:
+    """Cast a Sequence to a ctypes.Array of a given type."""
+    if isinstance(seq, Array):
+        return seq
+    arr_type = dtype * len(seq)
+    return arr_type(*seq)
